Crate assert_be_close

Crate assert_be_close 

Functions

assert_be_close
Asserts that two decimals are equal with the specified precision. On panic, the function will print the value of the decimal with their debug representations. 2つの小数が指定した精度で等しいことを保証する。 パニックになると、この関数は小数の値をデバッグ表現とともに出力する。
assert_not_close
Asserts that two decimals aren’t equal with the specified precision. On panic, the function will print the value of the decimal with their debug representations. 2つの小数が指定した精度で等しくないことを保証する。 パニックになると、この関数は小数の値をデバッグ表現とともに出力する。