pub fn assert_not_close<T: Float + Display>(left: T, right: T, precision: i32)Expand description
Asserts that two decimals aren’t equal with the specified precision. On panic, the function will print the value of the decimal with their debug representations. 2つの小数が指定した精度で等しくないことを保証する。 パニックになると、この関数は小数の値をデバッグ表現とともに出力する。
Panics
Panic if the value is equivalent to the specified precision. 値が指定した精度で等価であるとパニックする。
Examples
ⓘ
use assert_be_close::assert_not_close;
assert_not_close(1.0, 1.0001, 4);
assert_not_close(1.0, 1.0001, 3); // panic